<div align = "center"><img src = "https://www.newron.ai/newron-logo.svg" width=25% /></div>
<h1 align="center">
  newron-sdk - Just init().
</h1>
<br>


## Machine Learning, Made Simple

###### Newron is the machine learning platform for individuals and teams, designed for simplicity, speed and collaboration, and built to integrate with your favourite machine learning frameworks.
###### It provides a frictionless machine learning development experience to take care of the hard things: automatically track experiments, version models, reproduce models, visualize results and share findings within your the team or the broader ML community
###### It is easy to set up and enables ML engineers to develop, improve and deploy machine learning models with confidence and ease.

## Installation
<div align = "center"><img src = "https://raw.githubusercontent.com/NewronAI/NewronSDK/main/static/install.png" width=100% /></div>

## Usage 
```python
import newron
newron.init( "projectName","experimentName", "Description")
```
